Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1141)

Unified Diff: third_party/WebKit/Source/core/style/StyleDifference.h

Issue 1968123002: Revert of Improve handling of PaintInvalidationLayer (renamed to PaintInvalidationSubtree) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@LocationChange
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/style/StyleDifference.h
diff --git a/third_party/WebKit/Source/core/style/StyleDifference.h b/third_party/WebKit/Source/core/style/StyleDifference.h
index 6b4603096f60de5e25fea2efe592322e22b9552f..e5adf279e1329b1937ca0125b8a254bec9035230 100644
--- a/third_party/WebKit/Source/core/style/StyleDifference.h
+++ b/third_party/WebKit/Source/core/style/StyleDifference.h
@@ -45,13 +45,13 @@
bool needsPaintInvalidationObject() const { return m_paintInvalidationType == PaintInvalidationObject; }
void setNeedsPaintInvalidationObject()
{
- ASSERT(!needsPaintInvalidationSubtree());
+ ASSERT(!needsPaintInvalidationLayer());
m_paintInvalidationType = PaintInvalidationObject;
}
- // The object and its descendants need to issue paint invalidations.
- bool needsPaintInvalidationSubtree() const { return m_paintInvalidationType == PaintInvalidationSubtree; }
- void setNeedsPaintInvalidationSubtree() { m_paintInvalidationType = PaintInvalidationSubtree; }
+ // The layer and its descendant layers need to issue paint invalidations.
+ bool needsPaintInvalidationLayer() const { return m_paintInvalidationType == PaintInvalidationLayer; }
+ void setNeedsPaintInvalidationLayer() { m_paintInvalidationType = PaintInvalidationLayer; }
bool needsLayout() const { return m_layoutType != NoLayout; }
void clearNeedsLayout() { m_layoutType = NoLayout; }
@@ -92,7 +92,7 @@
enum PaintInvalidationType {
NoPaintInvalidation = 0,
PaintInvalidationObject,
- PaintInvalidationSubtree
+ PaintInvalidationLayer
};
unsigned m_paintInvalidationType : 2;

Powered by Google App Engine
This is Rietveld 408576698